@@ -111,7 +111,7 @@ sub get_perl_modules_from_ini {
     my $in = 0;
     my @modules;
     while ( my $line = <$fh> ) {
-        if ( '[Prereqs]' eq substr( $line, 0, 9 ) ) {
+        if ( $line =~ /^\[Prereqs/ ) {  ## no critic (Extended)
             $in++;
             next;
         }
@@ -411,6 +411,7 @@ sub name_overrides {
 # ABSTRACT: install dependencies with package manager or CPAN
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -419,7 +420,7 @@ install_deps.pl - install dependencies with package manager or CPAN
 
 =head1 VERSION
 
-version 0.20130521
+version 0.20130524
 
 =head1 AUTHORS
 
@@ -435,12 +436,15 @@ Davide Migliavacca <shari@cpan.org>
 
 =back
 
+=head1 CONTRIBUTOR
+
+ColocateUSA.net <company@colocateusa.net>
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by The Network People, Inc..
+This software is copyright (c) 2013 by ColocateUSA.com.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
