@@ -1,6 +1,6 @@
 package Mail::DMARC::Policy;
 {
-  $Mail::DMARC::Policy::VERSION = '0.20130521';
+  $Mail::DMARC::Policy::VERSION = '0.20130524';
 }
 use strict;
 use warnings;
@@ -165,7 +165,6 @@ sub is_valid {
 
 # ABSTRACT: a DMARC policy in object format
 
-
 =pod
 
 =head1 NAME
@@ -174,7 +173,7 @@ Mail::DMARC::Policy - a DMARC policy in object format
 
 =head1 VERSION
 
-version 0.20130521
+version 0.20130524
 
 =head1 EXAMPLES
 
@@ -420,16 +419,19 @@ Davide Migliavacca <shari@cpan.org>
 
 =back
 
+=head1 CONTRIBUTOR
+
+ColocateUSA.net <company@colocateusa.net>
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by The Network People, Inc..
+This software is copyright (c) 2013 by ColocateUSA.com.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-
 __END__
 sub {}
 
