@@ -1,6 +1,6 @@
 package Mail::DMARC::PurePerl;
 {
-  $Mail::DMARC::PurePerl::VERSION = '0.20130521';
+  $Mail::DMARC::PurePerl::VERSION = '0.20130524';
 }
 use strict;
 use warnings;
@@ -499,7 +499,6 @@ sub verify_external_reporting {
 
 # ABSTRACT: Pure Perl implementation of DMARC
 
-
 =pod
 
 =head1 NAME
@@ -508,7 +507,7 @@ Mail::DMARC::PurePerl - Pure Perl implementation of DMARC
 
 =head1 VERSION
 
-version 0.20130521
+version 0.20130524
 
 =head1 METHODS
 
@@ -607,16 +606,19 @@ Davide Migliavacca <shari@cpan.org>
 
 =back
 
+=head1 CONTRIBUTOR
+
+ColocateUSA.net <company@colocateusa.net>
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by The Network People, Inc..
+This software is copyright (c) 2013 by ColocateUSA.com.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-
 __END__
 sub {}
 
