@@ -1,6 +1,6 @@
 package Mail::DMARC::Report;
 {
-  $Mail::DMARC::Report::VERSION = '0.20130521';
+  $Mail::DMARC::Report::VERSION = '0.20130524';
 }
 use strict;
 use warnings;
@@ -73,7 +73,6 @@ sub save_aggregate {
 
 # ABSTRACT: A DMARC report interface
 
-
 =pod
 
 =head1 NAME
@@ -82,7 +81,7 @@ Mail::DMARC::Report - A DMARC report interface
 
 =head1 VERSION
 
-version 0.20130521
+version 0.20130524
 
 =head1 DESCRIPTION
 
@@ -216,16 +215,19 @@ Davide Migliavacca <shari@cpan.org>
 
 =back
 
+=head1 CONTRIBUTOR
+
+ColocateUSA.net <company@colocateusa.net>
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by The Network People, Inc..
+This software is copyright (c) 2013 by ColocateUSA.com.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-
 __END__
 sub {}
 
