@@ -1,6 +1,6 @@
 package Mail::DMARC::Report::Send::HTTP;
 {
-  $Mail::DMARC::Report::Send::HTTP::VERSION = '0.20130521';
+  $Mail::DMARC::Report::Send::HTTP::VERSION = '0.20130524';
 }
 use strict;
 use warnings;
@@ -43,7 +43,6 @@ sub post {
 
 # ABSTRACT: send DMARC reports via HTTP
 
-
 =pod
 
 =head1 NAME
@@ -52,7 +51,7 @@ Mail::DMARC::Report::Send::HTTP - send DMARC reports via HTTP
 
 =head1 VERSION
 
-version 0.20130521
+version 0.20130524
 
 =head1 12.2.2. HTTP
 
@@ -82,16 +81,19 @@ Davide Migliavacca <shari@cpan.org>
 
 =back
 
+=head1 CONTRIBUTOR
+
+ColocateUSA.net <company@colocateusa.net>
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by The Network People, Inc..
+This software is copyright (c) 2013 by ColocateUSA.com.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-
 __END__
 sub {}
 
