@@ -1,6 +1,6 @@
 package Mail::DMARC::Report::Send::SMTP;
 {
-  $Mail::DMARC::Report::Send::SMTP::VERSION = '0.20130521';
+  $Mail::DMARC::Report::Send::SMTP::VERSION = '0.20130524';
 }
 use strict;
 use warnings;
@@ -245,7 +245,6 @@ sub via_mime_lite {
 
 # ABSTRACT: send DMARC reports via SMTP
 
-
 =pod
 
 =head1 NAME
@@ -254,7 +253,7 @@ Mail::DMARC::Report::Send::SMTP - send DMARC reports via SMTP
 
 =head1 VERSION
 
-version 0.20130521
+version 0.20130524
 
 =head2 SUBJECT FIELD
 
@@ -330,16 +329,19 @@ Davide Migliavacca <shari@cpan.org>
 
 =back
 
+=head1 CONTRIBUTOR
+
+ColocateUSA.net <company@colocateusa.net>
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by The Network People, Inc..
+This software is copyright (c) 2013 by ColocateUSA.com.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-
 __END__
 sub {}
 
