@@ -1,6 +1,6 @@
 package Mail::DMARC::Report::Store;
 {
-  $Mail::DMARC::Report::Store::VERSION = '0.20130521';
+  $Mail::DMARC::Report::Store::VERSION = '0.20130524';
 }
 use strict;
 use warnings;
@@ -19,6 +19,11 @@ sub retrieve {
     return $self->backend->retrieve(@_);
 }
 
+sub retrieve_todo {
+    my $self = shift;
+    return $self->backend->retrieve_todo(@_);
+}
+
 sub backend {
     my $self    = shift;
     my $backend = $self->config->{report_store}{backend};
@@ -39,6 +44,7 @@ sub backend {
 
 # ABSTRACT: persistent storage broker for DMARC reports
 
+__END__
 
 =pod
 
@@ -48,13 +54,13 @@ Mail::DMARC::Report::Store - persistent storage broker for DMARC reports
 
 =head1 VERSION
 
-version 0.20130521
+version 0.20130524
 
 =head1 DESCRIPTION
 
-I struggled with choosing between a perl AnyDBM storage backend versus a SQL backend. I deployed with SQL because with a single SQL implementation, the user can choose from the wide availability of DBD drivers, including SQLite, MySQL, DBD (same as AnyDBM) and many others.
+I first toyed with perl's AnyDBM storage backend. I chose to deploy with SQL because with a single SQL implementation, the user can choose from the wide availability of DBD drivers, including SQLite, MySQL, DBD (same as AnyDBM) and many others.
 
-Others might like an alternative. This layer of indirection allows someone to write a new Mail::DMARC::Report::Store::MyGreatDB module, update their config file, and not alter the innards of Mail::DMARC.
+Others might like an alternative. This layer of indirection allows someone to write a new Mail::DMARC::Report::Store::MyGreatDB module, update their config file, and not alter the innards of Mail::DMARC. Much.
 
 =head1 AUTHORS
 
@@ -70,15 +76,15 @@ Davide Migliavacca <shari@cpan.org>
 
 =back
 
+=head1 CONTRIBUTOR
+
+ColocateUSA.net <company@colocateusa.net>
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by The Network People, Inc..
+This software is copyright (c) 2013 by ColocateUSA.com.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
