@@ -1,6 +1,6 @@
 package Mail::DMARC::Report::View;
 {
-  $Mail::DMARC::Report::View::VERSION = '0.20130521';
+  $Mail::DMARC::Report::View::VERSION = '0.20130524';
 }
 use strict;
 use warnings;
@@ -13,7 +13,6 @@ use parent 'Mail::DMARC::Base';
 
 # ABSTRACT: view DMARC report(s)
 
-
 =pod
 
 =head1 NAME
@@ -22,7 +21,7 @@ Mail::DMARC::Report::View - view DMARC report(s)
 
 =head1 VERSION
 
-version 0.20130521
+version 0.20130524
 
 =head1 DESCRIPTION
 
@@ -42,16 +41,19 @@ Davide Migliavacca <shari@cpan.org>
 
 =back
 
+=head1 CONTRIBUTOR
+
+ColocateUSA.net <company@colocateusa.net>
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by The Network People, Inc..
+This software is copyright (c) 2013 by ColocateUSA.com.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-
 __END__
 sub {}
 
