@@ -1,6 +1,6 @@
 package Mail::DMARC::Result;
 {
-  $Mail::DMARC::Result::VERSION = '0.20130521';
+  $Mail::DMARC::Result::VERSION = '0.20130524';
 }
 use strict;
 use warnings;
@@ -89,7 +89,7 @@ sub reason {
 
 package Mail::DMARC::Result::Reason;
 {
-  $Mail::DMARC::Result::Reason::VERSION = '0.20130521';
+  $Mail::DMARC::Result::Reason::VERSION = '0.20130524';
 }    ## no critic (MultiplePackages)
 use strict;
 use warnings;
@@ -127,7 +127,6 @@ sub comment {
 
 # ABSTRACT: the results of applying a policy
 
-
 =pod
 
 =head1 NAME
@@ -136,7 +135,7 @@ Mail::DMARC::Result - DMARC processing results
 
 =head1 VERSION
 
-version 0.20130521
+version 0.20130524
 
 =head1 OVERVIEW
 
@@ -232,16 +231,19 @@ Davide Migliavacca <shari@cpan.org>
 
 =back
 
+=head1 CONTRIBUTOR
+
+ColocateUSA.net <company@colocateusa.net>
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by The Network People, Inc..
+This software is copyright (c) 2013 by ColocateUSA.com.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-
 __END__
 sub {}
 
